==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1NetworkPolicyEgressRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NetworkPolicyEgressRuleFluent<A extends V1NetworkPolicyEgressRuleFluent<A>> extends Fluent<A>{


    public A addToPorts(int index,V1NetworkPolicyPort item);
    public A setToPorts(int index,V1NetworkPolicyPort item);
    public A addToPorts(V1NetworkPolicyPort... items);
    public A addAllToPorts(Collection<V1NetworkPolicyPort> items);
    public A removeFromPorts(V1NetworkPolicyPort... items);
    public A removeAllFromPorts(Collection<V1NetworkPolicyPort> items);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPort> getPorts();
    public List<V1NetworkPolicyPort> buildPorts();
    public V1NetworkPolicyPort buildPort(int index);
    public V1NetworkPolicyPort buildFirstPort();
    public V1NetworkPolicyPort buildLastPort();
    public V1NetworkPolicyPort buildMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public A withPorts(List<V1NetworkPolicyPort> ports);
    public A withPorts(V1NetworkPolicyPort... ports);
    public Boolean hasPorts();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> addNewPort();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> addNewPortLike(V1NetworkPolicyPort item);
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> setNewPortLike(int index,V1NetworkPolicyPort item);
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editPort(int index);
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editFirstPort();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editLastPort();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public A addToTo(int index,V1NetworkPolicyPeer item);
    public A setToTo(int index,V1NetworkPolicyPeer item);
    public A addToTo(V1NetworkPolicyPeer... items);
    public A addAllToTo(Collection<V1NetworkPolicyPeer> items);
    public A removeFromTo(V1NetworkPolicyPeer... items);
    public A removeAllFromTo(Collection<V1NetworkPolicyPeer> items);
    
/**
 * This method has been deprecated, please use method buildTo instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPeer> getTo();
    public List<V1NetworkPolicyPeer> buildTo();
    public V1NetworkPolicyPeer buildTo(int index);
    public V1NetworkPolicyPeer buildFirstTo();
    public V1NetworkPolicyPeer buildLastTo();
    public V1NetworkPolicyPeer buildMatchingTo(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public A withTo(List<V1NetworkPolicyPeer> to);
    public A withTo(V1NetworkPolicyPeer... to);
    public Boolean hasTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> addNewTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> addNewToLike(V1NetworkPolicyPeer item);
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> setNewToLike(int index,V1NetworkPolicyPeer item);
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editTo(int index);
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editFirstTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editLastTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editMatchingTo(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);

    public interface PortsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPortFluent<V1NetworkPolicyEgressRuleFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}
    public interface ToNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPeerFluent<V1NetworkPolicyEgressRuleFluent.ToNested<N>>{

        
    public N and();    public N endTo();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NetworkPolicyEgressRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NetworkPolicyEgressRuleFluent<A extends V1NetworkPolicyEgressRuleFluent<A>> extends Fluent<A>{


    public A addToPorts(int index,V1NetworkPolicyPort item);
    public A setToPorts(int index,V1NetworkPolicyPort item);
    public A addToPorts(V1NetworkPolicyPort... items);
    public A addAllToPorts(Collection<V1NetworkPolicyPort> items);
    public A removeFromPorts(V1NetworkPolicyPort... items);
    public A removeAllFromPorts(Collection<V1NetworkPolicyPort> items);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPort> getPorts();
    public List<V1NetworkPolicyPort> buildPorts();
    public V1NetworkPolicyPort buildPort(int index);
    public V1NetworkPolicyPort buildFirstPort();
    public V1NetworkPolicyPort buildLastPort();
    public V1NetworkPolicyPort buildMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public Boolean hasMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public A withPorts(List<V1NetworkPolicyPort> ports);
    public A withPorts(V1NetworkPolicyPort... ports);
    public Boolean hasPorts();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> addNewPort();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> addNewPortLike(V1NetworkPolicyPort item);
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> setNewPortLike(int index,V1NetworkPolicyPort item);
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editPort(int index);
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editFirstPort();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editLastPort();
    public V1NetworkPolicyEgressRuleFluent.PortsNested<A> editMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public A addToTo(int index,V1NetworkPolicyPeer item);
    public A setToTo(int index,V1NetworkPolicyPeer item);
    public A addToTo(V1NetworkPolicyPeer... items);
    public A addAllToTo(Collection<V1NetworkPolicyPeer> items);
    public A removeFromTo(V1NetworkPolicyPeer... items);
    public A removeAllFromTo(Collection<V1NetworkPolicyPeer> items);
    
/**
 * This method has been deprecated, please use method buildTo instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPeer> getTo();
    public List<V1NetworkPolicyPeer> buildTo();
    public V1NetworkPolicyPeer buildTo(int index);
    public V1NetworkPolicyPeer buildFirstTo();
    public V1NetworkPolicyPeer buildLastTo();
    public V1NetworkPolicyPeer buildMatchingTo(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public Boolean hasMatchingTo(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public A withTo(List<V1NetworkPolicyPeer> to);
    public A withTo(V1NetworkPolicyPeer... to);
    public Boolean hasTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> addNewTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> addNewToLike(V1NetworkPolicyPeer item);
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> setNewToLike(int index,V1NetworkPolicyPeer item);
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editTo(int index);
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editFirstTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editLastTo();
    public V1NetworkPolicyEgressRuleFluent.ToNested<A> editMatchingTo(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);

    public interface PortsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPortFluent<V1NetworkPolicyEgressRuleFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}
    public interface ToNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPeerFluent<V1NetworkPolicyEgressRuleFluent.ToNested<N>>{

        
    public N and();    public N endTo();
}


}
